@@ -142,6 +142,10 @@ class Tagger(_object):
     def what(*args): return _MeCab.Tagger_what(*args)
     __swig_destroy__ = _MeCab.delete_Tagger
     __del__ = lambda self : None;
+    __swig_getmethods__["create"] = lambda x: _MeCab.Tagger_create
+    if _newclass:create = staticmethod(_MeCab.Tagger_create)
+    __swig_getmethods__["version"] = lambda x: _MeCab.Tagger_version
+    if _newclass:version = staticmethod(_MeCab.Tagger_version)
     def __init__(self, *args):
         this = _MeCab.new_Tagger(*args)
         try: self.this.append(this)
@@ -149,6 +153,10 @@ class Tagger(_object):
     def parseToString(*args): return _MeCab.Tagger_parseToString(*args)
 _MeCab.Tagger_swigregister(Tagger)
 
+Tagger_create = _MeCab.Tagger_create
+
+Tagger_version = _MeCab.Tagger_version
+
 VERSION = _MeCab.VERSION
 
 
